bigchaindb-common
=================


.. image:: https://img.shields.io/pypi/v/bigchaindb-common.svg
        :target: https://pypi.python.org/pypi/bigchaindb-common

.. image:: https://img.shields.io/travis/bigchaindb/bigchaindb-common.svg
        :target: https://travis-ci.org/bigchaindb/bigchaindb-common

.. image:: https://img.shields.io/codecov/c/github/bigchaindb/bigchaindb-common/master.svg
    :target: https://codecov.io/github/bigchaindb/bigchaindb-common?branch=master

.. image:: https://readthedocs.org/projects/bigchaindb-common/badge/?version=latest
        :target: https://bigchaindb-common.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/bigchaindb/bigchaindb-common/shield.svg
     :target: https://pyup.io/repos/github/bigchaindb/bigchaindb-common/
     :alt: Updates


Set of reusable components for BigchainDB Python software.

* Development Status: Pre-Alpha
* The software is released under the terms of the Apache Software License 2.0
* Documentation: https://bigchaindb-common.readthedocs.io.


Features
--------

- Fully (de)serializable ``Transaction`` model of BigchainDB
- Support for the creation and signing of advanced
  `Cryptoconditions <https://github.com/bigchaindb/cryptoconditions>`_
- Easily overridable methods for easy adaptability of new concepts


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

